@@ -1,10 +1,23 @@
+"""Custom JSON encoder capable of rendering GeneralManager objects."""
+
 from datetime import datetime, date, time
 import json
 from general_manager.manager.generalManager import GeneralManager
 
 
 class CustomJSONEncoder(json.JSONEncoder):
-    def default(self, o):
+    """Serialise complex objects that appear within GeneralManager payloads."""
+
+    def default(self, o: object) -> object:
+        """
+        Convert unsupported objects into JSON-friendly representations.
+
+        Parameters:
+            o (Any): Object to encode.
+
+        Returns:
+            Any: JSON-serialisable representation of the object.
+        """
 
         # Serialize datetime objects as ISO strings
         if isinstance(o, (datetime, date, time)):
